# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class SDKAPIKeyCreatePermission(StrEnum):
    """
    Permission level for this key
    * `read` - Read Only
    * `write` - Read & Write
    * `admin` - Admin
    """

    READ = "read"
    WRITE = "write"
    ADMIN = "admin"



