# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class CleanAsyncRequestRequestOutputFormat(StrEnum):
    """
    * `html` - html
    * `markdown` - markdown
    """

    HTML = "html"
    MARKDOWN = "markdown"



class CleanRequestRequestOutputFormat(StrEnum):
    """
    * `html` - html
    * `markdown` - markdown
    * `aom` - aom
    * `xtree` - xtree
    """

    HTML = "html"
    MARKDOWN = "markdown"
    AOM = "aom"
    XTREE = "xtree"



class CleaningRequestDetailStatus(StrEnum):
    """
    * `pending` - Pending
    * `queued` - Queued
    * `processing` - Processing
    * `success` - Success
    * `error` - Error
    * `empty_result` - Empty Result
    * `cancelled` - Cancelled
    """

    PENDING = "pending"
    QUEUED = "queued"
    PROCESSING = "processing"
    SUCCESS = "success"
    ERROR = "error"
    EMPTY_RESULT = "empty_result"
    CANCELLED = "cancelled"



